@@ -2,34 +2,12 @@
     autodecryptverifyfilescontroller.cpp
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2008 Klarälvdalens Datakonsult AB
-                  2016 by Bundesamt für Sicherheit in der Informationstechnik
-    Software engineering by Intevation GmbH
+    SPDX-FileCopyrightText: 2008 Klarälvdalens Datakonsult AB
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    SPDX-FileCopyrightText: 2016 Bundesamt für Sicherheit in der Informationstechnik
+    SPDX-FileContributor: Intevation GmbH
 
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include <config-kleopatra.h>
@@ -45,7 +23,7 @@
 
 #include "commands/decryptverifyfilescommand.h"
 
-#include <utils/gnupg-helper.h>
+#include <Libkleo/GnuPG>
 #include <utils/path-helper.h>
 #include <utils/input.h>
 #include <utils/output.h>
@@ -65,8 +43,6 @@
 #include <QFileDialog>
 #include <QTemporaryDir>
 
-#include <memory>
-#include <vector>
 
 using namespace GpgME;
 using namespace Kleo;
@@ -109,17 +85,13 @@ public:
     std::vector<std::shared_ptr<const DecryptVerifyResult> > m_results;
     std::vector<std::shared_ptr<Task> > m_runnableTasks, m_completedTasks;
     std::shared_ptr<Task> m_runningTask;
-    bool m_errorDetected;
-    DecryptVerifyOperation m_operation;
-    DecryptVerifyFilesDialog *m_dialog;
-    QTemporaryDir *m_workDir;
+    bool m_errorDetected = false;
+    DecryptVerifyOperation m_operation = DecryptVerify;
+    DecryptVerifyFilesDialog *m_dialog = nullptr;
+    QTemporaryDir *m_workDir = nullptr;
 };
 
-AutoDecryptVerifyFilesController::Private::Private(AutoDecryptVerifyFilesController *qq) : q(qq),
-    m_errorDetected(false),
-    m_operation(DecryptVerify),
-    m_dialog(nullptr),
-    m_workDir(nullptr)
+AutoDecryptVerifyFilesController::Private::Private(AutoDecryptVerifyFilesController *qq) : q(qq)
 {
     qRegisterMetaType<VerificationResult>();
 }
