@@ -1,38 +1,14 @@
 /*  crypto/gui/certificatelineedit.cpp
 
     This file is part of Kleopatra, the KDE keymanager
-    Copyright (c) 2016 by Bundesamt für Sicherheit in der Informationstechnik
-    Software engineering by Intevation GmbH
+    SPDX-FileCopyrightText: 2016 Bundesamt für Sicherheit in der Informationstechnik
+    SPDX-FileContributor: Intevation GmbH
 
-    Kleopatra is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    Kleopatra is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-    In addition, as a special exception, the copyright holders give
-    permission to link the code of this program with any edition of
-    the Qt library by Trolltech AS, Norway (or with modified versions
-    of Qt that use the same license as Qt), and distribute linked
-    combinations including the two.  You must obey the GNU General
-    Public License in all respects for all of the code used other than
-    Qt.  If you modify this file, you may extend this exception to
-    your version of the file, but you are not obligated to do so.  If
-    you do not wish to do so, delete this exception statement from
-    your version.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "certificatelineedit.h"
 
-#include <QLineEdit>
 #include <QCompleter>
 #include <QFontMetrics>
 #include <QPushButton>
@@ -41,7 +17,6 @@
 
 #include "kleopatra_debug.h"
 
-#include "dialogs/certificateselectiondialog.h"
 #include "commands/detailscommand.h"
 
 #include <Libkleo/KeyCache>
@@ -107,16 +82,12 @@ CertificateLineEdit::CertificateLineEdit(AbstractKeyListModel *model,
     : QLineEdit(parent),
       mFilterModel(new KeyListSortFilterProxyModel(this)),
       mFilter(std::shared_ptr<KeyFilter>(filter)),
-      mEditStarted(false),
-      mEditFinished(false),
       mLineAction(new QAction(this))
 {
     setPlaceholderText(i18n("Please enter a name or email address..."));
     setClearButtonEnabled(true);
     addAction(mLineAction, QLineEdit::LeadingPosition);
 
-    QFontMetrics fm(font());
-
     auto *completer = new QCompleter(this);
     auto *completeFilterModel = new ProxyModel(completer);
     completeFilterModel->setKeyFilter(mFilter);
