@@ -2,21 +2,9 @@
     command.cpp
 
     This file is part of KleopatraClient, the Kleopatra interface library
-    Copyright (c) 2008 Klarälvdalens Datakonsult AB
+    SPDX-FileCopyrightText: 2008 Klarälvdalens Datakonsult AB
 
-    KleopatraClient is free software; you can redistribute it and/or modify
-    it under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    KleopatraClient is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include <config-kleopatra.h>
@@ -44,6 +32,7 @@
 
 #include <assuan.h>
 #include <gpg-error.h>
+#include <gpgme++/global.h>
 
 #include <algorithm>
 #include <string>
@@ -438,16 +427,8 @@ static QString to_error_string(int err)
 
 static QString gnupg_home_directory()
 {
-#ifdef Q_OS_WIN
-    return QFile::decodeName(default_homedir());
-#else
-    const QByteArray gnupgHome = qgetenv("GNUPGHOME");
-    if (!gnupgHome.isEmpty()) {
-        return QFile::decodeName(gnupgHome);
-    } else {
-        return QDir::homePath() + QLatin1String("/.gnupg");
-    }
-#endif
+    static const char *hDir = GpgME::dirInfo("homedir");
+    return QFile::decodeName(hDir);
 }
 
 static QString get_default_socket_name()
@@ -620,11 +601,7 @@ void Command::Private::run()
         // give it a bit of time to start up and try a couple of times
         for (int i = 0; err && i < 20; ++i) {
             msleep(500);
-#ifndef HAVE_ASSUAN2
-            err = assuan_socket_connect(&naked_ctx, QFile::encodeName(socketName).constData(), -1);
-#else
-            err = assuan_socket_connect(ctx.get(), QFile::encodeName(socketName).constData(), -1, 0);
-#endif
+            err = assuan_socket_connect(ctx.get(), socketName.toUtf8().constData(), -1, 0);
         }
     }
 
